# Security Policy

## Supported Versions

Currently all versions of this project are supported. 

## Reporting a Vulnerability

Security vulnerabilities can be reported by email to `maasch@rogers.com` and they will be addressed as soon as possible. 
